This patch allows using NPE-B without having to provide
firmware for NPE-C. NPE-C can still be used once a board
config specifies CONFIG_HAS_ETH1.

Signed-off-by: Hendrik Sattler

---
 cpu/ixp/npe/IxEthDBFeatures.c |    4 ++++
 cpu/ixp/npe/npe.c             |   13 +++++++++++++
 2 files changed, 17 insertions(+)

--- u-boot-1.3.4.orig/cpu/ixp/npe/IxEthDBFeatures.c
+++ u-boot-1.3.4/cpu/ixp/npe/IxEthDBFeatures.c
@@ -82,6 +82,10 @@
         /* check and bypass if NPE B or C is fused out */
         if (ixEthDBSingleEthNpeCheck(portIndex) != IX_ETH_DB_SUCCESS) continue;
 
+#ifndef CONFIG_HAS_ETH1
+	if (portIndex == 1) continue;
+#endif
+
         /* all ports are capable of LEARNING by default */
         portInfo->featureCapability |= IX_ETH_DB_LEARNING;
         portInfo->featureStatus     |= IX_ETH_DB_LEARNING;
--- u-boot-1.3.4.orig/cpu/ixp/npe/npe.c
+++ u-boot-1.3.4/cpu/ixp/npe/npe.c
@@ -316,12 +316,14 @@
 		return 0;
 	}
 
+#ifdef CONFIG_HAS_ETH1
 	if (npe_used[IX_ETH_PORT_2] && npe_exists[IX_ETH_PORT_2] &&
 	    ixNpeDlNpeInitAndStart(IX_NPEDL_NPEIMAGE_NPEC_ETH_LEARN_FILTER_SPAN_FIREWALL_VLAN_QOS)
 	    != IX_SUCCESS) {
 		printf("Error downloading firmware to NPE-C!\n");
 		return 0;
 	}
+#endif
 
 	/* don't need this for U-Boot */
 	ixFeatureCtrlSwConfigurationWrite(IX_FEATURECTRL_ETH_LEARNING, FALSE);
@@ -645,9 +647,11 @@
 					    IX_FEATURE_CTRL_COMPONENT_ENABLED)
 						npe_exists[IX_ETH_PORT_1] = TRUE;
 
+#ifdef CONFIG_HAS_ETH1
 					if (ixFeatureCtrlComponentCheck(IX_FEATURECTRL_ETH1) ==
 					    IX_FEATURE_CTRL_COMPONENT_ENABLED)
 						npe_exists[IX_ETH_PORT_2] = TRUE;
+#endif
 					break;
 				case IX_FEATURE_CTRL_SILICON_TYPE_A0:
 					/*
@@ -655,7 +659,9 @@
 					 * are available.
 					 */
 					npe_exists[IX_ETH_PORT_1] = TRUE;
+#ifdef CONFIG_HAS_ETH1
 					npe_exists[IX_ETH_PORT_2] = TRUE;
+#endif
 					break;
 				}
 			} else if (ixFeatureCtrlDeviceRead() == IX_FEATURE_CTRL_DEVICE_TYPE_IXP46X) {
@@ -663,13 +669,20 @@
 				    IX_FEATURE_CTRL_COMPONENT_ENABLED)
 					npe_exists[IX_ETH_PORT_1] = TRUE;
 
+#ifdef CONFIG_HAS_ETH1
 				if (ixFeatureCtrlComponentCheck(IX_FEATURECTRL_ETH1) ==
 				    IX_FEATURE_CTRL_COMPONENT_ENABLED)
 					npe_exists[IX_ETH_PORT_2] = TRUE;
+#endif
 			}
 
 			npe_used[IX_ETH_PORT_1] = 1;
+#ifdef CONFIG_HAS_ETH1
 			npe_used[IX_ETH_PORT_2] = 1;
+#else
+			npe_used[IX_ETH_PORT_2] = 0;
+			npe_exists[IX_ETH_PORT_2] = FALSE;
+#endif
 
 			npe_alloc_end = npe_alloc_pool + sizeof(npe_alloc_pool);
 			npe_alloc_free = (u8 *)(((unsigned)npe_alloc_pool +
